@@ -27,23 +27,56 @@ MS_3RD = resource_filename('virt.firmware', 'certs/MicrosoftCorporationUEFICA201
 
 # linux distro ca keys
 DISTRO_CA = {
-    'windows' : [
-        MS_WIN,
-    ],
-    'rhel' : [
-        resource_filename('virt.firmware', 'certs/RedHatSecureBootCA3.pem'),
-        resource_filename('virt.firmware', 'certs/RedHatSecureBootCA5.pem'),
-        resource_filename('virt.firmware', 'certs/RedHatSecureBootCA6.pem'),
-    ],
-    'fedora' : [
-        resource_filename('virt.firmware', 'certs/fedoraca-20200709.pem'),
-    ],
-    'centos' : [
-        resource_filename('virt.firmware', 'certs/CentOSSecureBootCAkey1.pem'),
-        resource_filename('virt.firmware', 'certs/CentOSSecureBootCA2.pem'),
+    'windows' : {
+        'desc'  : 'Microsoft Windows',
+        'certs' : [
+            MS_WIN,
+        ],
+    },
+    'rhel-2014' : {
+        'desc'  : 'Red Hat Enterprise Linux (obsoleted by 2020 signing key rotation)',
+        'certs' : [
+            resource_filename('virt.firmware', 'certs/RedHatSecureBootCA3.pem'),
+        ],
+    },
+    'rhel' : {
+        'desc'  : 'Red Hat Enterprise Linux',
+        'certs' : [
+            resource_filename('virt.firmware', 'certs/RedHatSecureBootCA5.pem'),
+            resource_filename('virt.firmware', 'certs/RedHatSecureBootCA8.pem'),
     ],
+    },
+    'rh-uefi' : {
+        'desc'  : 'Red Hat UEFI CA',
+        'certs' : [
+            resource_filename('virt.firmware', 'certs/RedHatUEFICA2023.pem'),
+        ],
+    },
+    'fedora' : {
+        'desc'  : 'Fedora Linux',
+        'certs' : [
+            resource_filename('virt.firmware', 'certs/fedoraca-20200709.pem'),
+        ],
+    },
+    'centos-2018' : {
+        'desc'  : 'CentOS Stream (obsoleted by 2020 signing key rotation)',
+        'certs' : [
+            resource_filename('virt.firmware', 'certs/CentOSSecureBootCAkey1.pem'),
+        ],
+    },
+    'centos' : {
+        'desc'  : 'CentOS Stream',
+        'certs' : [
+            resource_filename('virt.firmware', 'certs/CentOSSecureBootCA2.pem'),
+        ],
+    },
 }
 
+def list_distros():
+    print('known distro certs:')
+    for (key, val) in DISTRO_CA.items():
+        print(f'  {key:12s} - {val["desc"]}')
+
 def pk_generate(cn = 'random secure boot platform',
                 org = None, city = None, state = None, country = None):
     key = rsa.generate_private_key(
@@ -64,6 +97,7 @@ def pk_generate(cn = 'random secure boot platform',
         attrs.append(x509.NameAttribute(x509.NameOID.COUNTRY_NAME, country))
 
     subject = issuer = x509.Name(attrs)
+    now = datetime.datetime.now(datetime.timezone.utc)
     cert = x509.CertificateBuilder().subject_name(
         subject
     ).issuer_name(
@@ -73,9 +107,9 @@ def pk_generate(cn = 'random secure boot platform',
     ).serial_number(
         x509.random_serial_number()
     ).not_valid_before(
-        datetime.datetime.utcnow()
+        now
     ).not_valid_after(
-        datetime.datetime.utcnow() + datetime.timedelta(days = 365 * 10)
+        now + datetime.timedelta(days = 365 * 10)
     ).add_extension(
         x509.BasicConstraints(ca = False, path_length = None),
         critical = False,
